@@ -26,6 +26,22 @@
 #define PYTHON2_EXT_CDTOR_DECL(name) Python2##name##Extension(QObject* parent); \
                                      ~Python2##name##Extension();
 
+class Python2LinearAlgebraExtension : public Cantor::LinearAlgebraExtension
+{
+    public:
+    PYTHON2_EXT_CDTOR_DECL(LinearAlgebra)
+    virtual QString createVector(const QStringList& entries, VectorType type);
+    virtual QString nullVector(int size, VectorType type);
+    virtual QString createMatrix(const Cantor::LinearAlgebraExtension::Matrix& matrix);
+    virtual QString identityMatrix(int size);
+    virtual QString nullMatrix(int rows, int columns);
+    virtual QString rank(const QString& matrix);
+    virtual QString invertMatrix(const QString& matrix);
+    virtual QString charPoly(const QString& matrix);
+    virtual QString eigenVectors(const QString& matrix);
+    virtual QString eigenValues(const QString& matrix);
+};
+
 class Python2PackagingExtension : public Cantor::PackagingExtension
 {
     public:
@@ -33,6 +49,14 @@ class Python2PackagingExtension : public Cantor::PackagingExtension
     virtual QString importPackage(const QString& module);
 };
 
+class Python2PlotExtension : public Cantor::PlotExtension
+{
+    public:
+    PYTHON2_EXT_CDTOR_DECL(Plot)
+    virtual QString plotFunction2d(const QString& function, const QString& variable, const QString& left, const QString& right);
+    virtual QString plotFunction3d(const QString& function, VariableParameter var1, VariableParameter var2);
+};
+
 class Python2ScriptExtension : public Cantor::ScriptExtension
 {
     public:
